; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.


;-| Super Motions |--------------------------------------------------------
[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

[Command]
name = "Wacky!"
command = U, D, U, D, DF, UF, B, x
time = 1

[Command]
name = "TripleUpper"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command] 
name = "TripleUpper"   
command = ~D, DF, F, D, DF, F, y
time = 20

[Command] 
name = "TripleUpper"  
command = ~D, DF, F, D, DF, F, z
time = 20

[Command]
name = "FlurryPunch"
command = ~D, DF, F, D, DF, F, a
time = 20

[Command]
name = "FlurryPunch"
command = ~D, DF, F, D, DF, F, b
time = 20

[Command]
name = "FlurryPunch"
command = ~D, DF, F, D, DF, F, c
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_z"
command = ~D, DF, F, z

[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

[Command]
name = "DP_z"
command = ~F, D, DF, F, z

[Command]
name = "DP_x"
command = ~F, D, DF, F, x

[Command]
name = "DP_y"
command = ~F, D, DF, F, y

[Command]
name = "CHG_x"
command = ~45$B, F, x

[Command]
name = "CHG_y"
command = ~45$B, F, y

[Command]
name = "CHG_z"
command = ~45$B, F, z 

[Command]
name = "Callblaze"
command = x+a

[Command]
name = "Callmax"
command = y+b

[Command]
name = "Callskate"
command = z+c

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-|Pressing Down + Button |-------------------------------------------------
[Command]
name = "dwnx"
command = /$D, x


[Command]
name = "dwny"
command = /$D, y


[Command]
name = "dwnz"
command = /$D, z


[Command] 
name = "dwna"
command = /$D, a


[Command]
name = "dwnb"
command = /$D, b


[Command]
name = "dwnc"
command = /$D, c


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;Triple Uppercut (uses one super bar)
[State -1, Triple Uppercut]
type = ChangeState
value = 3000
triggerall = command = "TripleUpper"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = StateNo = 200 || StateNo = 210 || StateNo = 225
trigger2 = movecontact

;---------------------------------------------------------------------------
; Flurry Punch (uses one super bar)
[State -1, Flurry Punch]
type = ChangeState
value = 3100
triggerall = command = "FlurryPunch"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Rising Upper (light)
[State -1, Rising Upper Light]
type = ChangeState
value = 1002
triggerall = command = "DP_x"
triggerall = ctrl
trigger1 = statetype = S
;trigger1 = ctrl

;---------------------------------------------------------------------------
;Rising Upper (med)
[State -1, Rising Upper Med]
type = ChangeState
value = 1003
triggerall = command = "DP_y"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Rising Upper (hard)
[State -1, Rising Upper]
type = ChangeState
value = 1000
triggerall = command = "DP_z"
trigger1 = statetype = S
trigger1 = ctrl


;---------------------------------------------------------------------------
; Grand Upper (light punch)
[State -1, Light Grand Upper]
type = ChangeState
value = 1020
triggerall = command = "QCF_x"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499]) ;Cancel ground moves
trigger2 = movecontact

;---------------------------------------------------------------------------
; Grand Upper (med punch)
[State -1, Medium Grand Upper]
type = ChangeState
value = 1030
triggerall = command = "QCF_y"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Grand Upper (hard punch)
[State -1, Hard Grand Upper]
type = ChangeState
value = 1040
triggerall = command = "QCF_z"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Dragon Circle
[State -1, Dragon Circle]
type = ChangeState
value = 1010
triggerall = command = "CHG_x" || command = "CHG_y" || command = "CHG_z"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Spin Kick (aerial)
[State -1, Air Spin Kick]
type = Changestate
value = 1061
triggerall = command = "QCB_a" || command = "QCB_b" || command = "QCB_c"
triggerall = ctrl
trigger1 = statetype = A

;---------------------------------------------------------------------------
; Spin Kick (light)
[State -1, Spin Kick]
type = ChangeState
value = 1050
triggerall = command = "QCB_a"
trigger1 = statetype = S
trigger1 = ctrl

;----------------------------------------------------------------------------
; Spin Kick (med)
[State -1, Spin Kick Med]
type = Changestate
value = 1070
triggerall = command = "QCB_b"
trigger1 = ctrl


;----------------------------------------------------------------------------
; Spin Kick (hard)
[State -1, Spin Kick Hard]
type = Changestate
value = 1060
triggerall = command = "QCB_c"
trigger1 = ctrl

;----------------------------------------------------------------------------
; Call Blaze
[State -1, Call Blaze]
type = ChangeState
value = 9000
triggerall = command = "Callblaze"
triggerall = power >= 250
triggerall = numhelper(600) != 1
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Call Max
[State -1, Call Max]
type = Changestate
value = 9010
triggerall = command = "Callmax"
triggerall = power >= 300
triggerall = numhelper(700) != 1
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Call Skate
[State -1, Call Skate]
type = Changestate
value = 9020
triggerall = command = "Callskate"
triggerall = power >= 300
triggerall = numhelper(800) != 1
trigger1 = statetype = S
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand_Throw
;
[State -1, Standing Throw]
type = ChangeState
value = 800
triggerall = command = "z" || command = "y"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
; Headbutt
[State -1, Headbutt]
type = ChangeState
value = 225
triggerall = command = "fwd_z"
triggerall = command != "holddown"
triggerall = ctrl = 1
triggerall = p2stateno != 5000
trigger1 = statetype = S

;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x" || command = "dwnx"
;triggerall = command != "holddown"
trigger1 = statetype = S || statetype = C
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 7

;---------------------------------------------------------------------------
;Stand Medium Punch
;p`
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = command = "y" || command = "dwny"
;triggerall = command != "holddown"
trigger1 = statetype = S || statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 2
trigger3 = (stateno = 230) && time > 3

;---------------------------------------------------------------------------
;Stand Hard Punch
;p`
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = command = "z" || command = "dwnz"
;triggerall = command != "holddown"
trigger1 = statetype = S || statetype = C
trigger1 = ctrl
trigger2 = (stateno = 210) && time > 5
trigger3 = (stateno = 240) && time > 6

;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a" || command = "dwna"
;triggerall = command != "holddown"
trigger1 = statetype = S || statetype = C
trigger1 = ctrl


;---------------------------------------------------------------------------
;Standing Medium Kick
;LbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = command = "b" || command = "dwnb"
;triggerall = command != "holddown"
trigger1 = statetype = S || statetype = C
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = movecontact

;---------------------------------------------------------------------------
;Standing Hard Kick
;LbN
[State -1, Standing Hard Kick]
type = ChangeState
value = 250
triggerall = command = "c" || command = "dwnc"
;triggerall = command != "holddown"
trigger1 = statetype = S || statetype = C
trigger1 = ctrl
trigger2 = (stateno = 240) || (stateno = 230)
trigger2 = movecontact

;----------------------------------------------------------------------------
; Vertical Light Punch
[State -1, Vert Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = vel X = 0
trigger1 = ctrl

;----------------------------------------------------------------------------
; Vertical Medium Punch
[State -1, Vert Med Punch]
type = ChangeState
value = 401
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = vel X = 0
trigger1 = ctrl

;----------------------------------------------------------------------------
; Vertical Hard Punch
[State -1, Vert Hard Punch]
type = ChangeState
value = 402
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = vel X = 0
trigger1 = ctrl

;----------------------------------------------------------------------------
; Vertical Light Kick
[State -1, Vert Light Kick]
type = ChangeState
value = 410
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = vel X = 0
trigger1 = ctrl

;----------------------------------------------------------------------------
; Vertical Med Kick
[State -1, Vert Med Kick]
type = ChangeState
value = 411
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = vel X = 0
trigger1 = ctrl

;----------------------------------------------------------------------------
; Vertical Hard Kick
[State -1, Vert Hard Kick]
type = ChangeState
value = 412
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = vel X = 0
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 7

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Hard Punch
[State -1, Jump Hard Punch]
type = ChangeState
value = 620
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Strong Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Hard Kick
;󒆋LbN
[State -1, Jump Hard Kick]
type = ChangeState
value = 650
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl

